@@ -1,3 +1,4 @@
-from download import fetch_file, fetch_and_transform, fetch_csv_dataframe, fetch_fasta_dict
+from download import fetch_file, fetch_and_transform, fetch_csv_dataframe
+from fasta import fetch_fasta_dict
 from db import fetch_fasta_db, db_from_dataframe, fetch_csv_db, create_db
 from common import ensure_dir, get_data_dir, build_path, clear_cache
