@@ -96,11 +96,13 @@ def fetch_file(download_url, filename = None, decompress = False, subdir = None)
     # if no filename provided, use the original filename on the server
     if not filename:
         filename = split(download_url)[1]
+        
+
 
     # if the url pointed to a directory then just replace all the special chars
-    if not filename:
-        filename = re.sub("/|\\|;|\.|:|\?|=", "_", download_url)
-
+    filename = re.sub("/|\\|;|:|\?|=", "_", download_url)
+    filename = filename[-80:]
+    
     if decompress:
         (base, ext) = splitext(filename)
         if ext in (".gz", ".zip"):
@@ -127,7 +129,7 @@ def fetch_and_transform(
     """
     transformed_path = build_path(transformed_filename, subdir)
     if not exists(transformed_path):
-        source_path = fetch_file(source_filename, source_url, subdir)
+        source_path = fetch_file(source_url, source_filename, subdir)
         result = transformer(source_path, transformed_path)
     else:
         result = loader(transformed_path)
